%define anolis_release 5

%bcond_with xmvn_generator

%bcond_without ivy

%global python_prefix python3
%global python_interpreter %{?__python3}%{!?__python3:dummy}

%global default_flavour 17

%global default_jdk %{_prefix}/lib/jvm/java-%{default_flavour}-openjdk
%global default_jre %{_prefix}/lib/jvm/jre-%{default_flavour}-openjdk

%global maven_home %{_datadir}/xmvn

Name:           javapackages-tools
Version:        6.1.0
Release:        %{anolis_release}%{?dist}
Summary:        Macros and scripts for Java packaging support
License:        BSD
URL:            https://github.com/fedora-java/javapackages
BuildArch:      noarch

Source0:        https://github.com/fedora-java/javapackages/archive/%{version}.tar.gz
Source3:        javapackages-config.json

Source8:        toolchains-openjdk8.xml
Source11:       toolchains-openjdk11.xml
Source17:       toolchains-openjdk17.xml

Patch0:         0001-Remove-annotation-removal-scripts.patch

BuildRequires:  make
BuildRequires:  which
BuildRequires:  xmlto
BuildRequires:  asciidoc
BuildRequires:  coreutils
BuildRequires:  %{python_prefix}-lxml
BuildRequires:  %{python_prefix}-devel
BuildRequires:  %{python_prefix}-pytest
BuildRequires:  %{python_prefix}-setuptools

Requires:       which
Requires:       coreutils
Requires:       findutils
Requires:       javapackages-filesystem = %{version}-%{release}
Requires:       java-%{default_flavour}-openjdk-headless

Provides:       jpackage-utils = %{version}-%{release}

%description
Javapackages-tools is a collection of tools and scripts that are designed to
provide a standardized approach to Java package management in Linux
distributions. These tools help with the creation, installation, and removal
of Java packages, and they also provide a consistent directory structure for
Java packages.

The main components of Javapackages-tools include:

Javapackages-filesystem: This component defines a standard directory
structure for Java packages. It specifies the locations for Java libraries,
configuration files, and binaries. This standard directory structure makes it
easier to manage and install Java packages across different Linux
distributions.

Javapackages-tools: This component provides a command-line interface for
managing Java packages. It includes tools for creating, installing, and
removing Java packages. It also provides tools for querying the package
database and checking package dependencies.

Javapackages-maven-plugin: This component is a plugin for the Maven build
system. It provides support for building Java packages that conform to the
Javapackages-filesystem standard. This plugin generates RPM or DEB packages
that can be easily installed on Linux systems.

Javapackages-local: This component provides a way to install Java packages
locally without requiring administrative privileges. This is useful for
testing and development purposes, where developers may not have access to the
system-wide package database.

Javapackages-ivy: This component provides integration with the Ivy
dependency management system. It allows Java packages to be installed and
managed using Ivy, which can simplify the process of managing complex Java
applications.

Overall, Javapackages-tools is a useful collection of tools for managing Java
packages in Linux distributions. It provides a standardized approach to Java
package management, which can make it easier to create, install, and remove
Java packages across different Linux distributions.

%package -n javapackages-filesystem
Summary:        Java packages filesystem layout
Provides:       eclipse-filesystem = %{version}-%{release}

%description -n javapackages-filesystem
This package provides some basic directories into which Java packages
install their content.

%package -n maven-local
Summary:        Macros and scripts for Maven packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       xmvn-minimal
Requires:       mvn(org.fedoraproject.xmvn:xmvn-mojo)
Requires:       mvn(org.apache.maven.plugins:maven-compiler-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-jar-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-resources-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-surefire-plugin)

%description -n maven-local
This package provides macros and scripts to support packaging Maven artifacts.

%if %{with ivy}
%package -n ivy-local
Summary:        Local mode for Apache Ivy
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       apache-ivy >= 2.3.0-8
Requires:       xmvn-connector-ivy

%description -n ivy-local
This package implements local mode for Apache Ivy, which allows
artifact resolution using XMvn resolver.
%endif

%package -n %{python_prefix}-javapackages
Summary:        Module for handling various files for Java packaging
Requires:       %{python_prefix}-lxml

%description -n %{python_prefix}-javapackages
Module for handling, querying and manipulating of various files for Java
packaging in Linux distributions

%package -n javapackages-local
Summary:        Non-essential macros and scripts for Java packaging support
Requires:       javapackages-common = %{version}-%{release}
# Java build systems don't have hard requirement on java-devel, so it should be there
Requires:       java-%{default_flavour}-openjdk-devel
Requires:       xmvn-tools
%if %{with xmvn_generator}
Requires:       xmvn-generator
%endif

%description -n javapackages-local
This package provides non-essential macros and scripts to support Java packaging.

%package -n javapackages-generators
Summary:        RPM dependency generators for Java packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       %{python_prefix}-javapackages = %{version}-%{release}
Requires:       %{python_interpreter}

%description -n javapackages-generators
RPM dependency generators to support Java packaging.

%package -n javapackages-common
Summary:        Non-essential macros and scripts for Java packaging support
Requires:       javapackages-generators = %{version}-%{release}

%description -n javapackages-common
This package provides non-essential, but commonly used macros and
scripts to support Java packaging.

%package -n javapackages-extra
Summary:        Rarely-used macros and scripts for Java packaging support
Requires:       javapackages-common = %{version}-%{release}
Requires:       jurand

%description -n javapackages-extra
This package provides rarely-used and obsolete macros and scripts to
support Java packaging.

%package -n maven-local-openjdk8
Summary:        OpenJDK 8 toolchain for XMvn
RemovePathPostfixes: -openjdk8
Requires:       maven-local
Requires:       java-1.8.0-openjdk-devel

%description -n maven-local-openjdk8
OpenJDK 8 toolchain for XMvn

%package -n maven-local-openjdk11
Summary:        OpenJDK 11 toolchain for XMvn
RemovePathPostfixes: -openjdk11
Requires:       maven-local
Requires:       java-11-openjdk-devel

%description -n maven-local-openjdk11
OpenJDK 11 toolchain for XMvn

%package -n maven-local-openjdk17
Summary:        OpenJDK 17 toolchain for XMvn
RemovePathPostfixes: -openjdk17
Requires:       maven-local
Requires:       java-17-openjdk-devel

%description -n maven-local-openjdk17
OpenJDK 17 toolchain for XMvn

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{EVR}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -p1 -n javapackages-%{version}

sed -i /javapackages-metadata.xml/d install

%build
%configure --pyinterpreter=%{python_interpreter} \
    --default_jdk=%{default_jdk} --default_jre=%{default_jre} \
    --rpmmacrodir=%{rpmmacrodir}
./build

%install
./install

sed -e 's/.[17]$/&*/' -i files-*

rm -rf %{buildroot}%{_bindir}/gradle-local
rm -rf %{buildroot}%{_datadir}/gradle-local
rm -rf %{buildroot}%{_mandir}/man7/gradle_build.7
%if %{without ivy}
rm -rf %{buildroot}%{_sysconfdir}/ivy
rm -rf %{buildroot}%{_sysconfdir}/ant.d
%endif

mkdir -p %{buildroot}%{maven_home}/conf/
cp -p %{SOURCE8} %{buildroot}%{maven_home}/conf/toolchains.xml-openjdk8
cp -p %{SOURCE11} %{buildroot}%{maven_home}/conf/toolchains.xml-openjdk11
cp -p %{SOURCE17} %{buildroot}%{maven_home}/conf/toolchains.xml-openjdk17

install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/java/javapackages-config.json

%check
./check

%files -f files-tools

%files -n javapackages-filesystem -f files-filesystem

%files -n javapackages-generators -f files-generators

%files -n javapackages-common -f files-common

%files -n javapackages-extra

%files -n javapackages-local

%files -n maven-local

%if %{with ivy}
%files -n ivy-local -f files-ivy
%endif

%files -n maven-local-openjdk8
%dir %{maven_home}/conf
%{maven_home}/conf/toolchains.xml-openjdk8

%files -n maven-local-openjdk11
%dir %{maven_home}/conf
%{maven_home}/conf/toolchains.xml-openjdk11

%files -n maven-local-openjdk17
%dir %{maven_home}/conf
%{maven_home}/conf/toolchains.xml-openjdk17

%files -n %{python_prefix}-javapackages -f files-python
%license LICENSE

%files doc
%doc README.md TODO VERSION

%changelog
* Tue Mar 12 2024 Bo Ren <rb01097748@alibaba-inc.com> - 6.1.0-5
- Rebuild with python3.11

* Sun May 07 2023 Funda Wang <fundawang@yeah.net> - 6.1.0-4
- Set default flavour as 17

* Sat Apr 15 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 6.1.0-3
- Update the description

* Mon Apr 10 2023 Funda Wang <fundawang@yeah.net> - 6.1.0-2
- Set default flavour of jre

* Mon Mar 27 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 6.1.0-1
- update to 6.1.0

* Thu Jun 09 2022 happy_orange <songnannan@linux.alibaba.com> - 6.0.0-1
- init from upstream
